@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.c,v 1.11 2003/06/06 19:37:23 fuyu Exp $
+ * $Id: bbs_thread_ui.c,v 1.14 2003/06/16 18:32:16 fuyu Exp $
  */
 
 #include "config.h"
@@ -476,7 +476,7 @@ open_bbs_thread(OchushaApplication *application, OchushaBBSThread *thread,
 
       setup_for_tab_label_animation(buffer, tab_label);
 
-      info->dat_buffer = buffer;
+      info->response_source_buffer = buffer;
       info->rendering_done = FALSE;
 
       job_args->application = application;
@@ -951,11 +951,12 @@ render_response(OchushaBBSThread *thread, gint number,
   gdk_threads_enter();
 
 #if ENABLE_RENDERING_ON_IDLE
-  while (!try_get_rendering_right(context->application, info->dat_buffer,
+  while (!try_get_rendering_right(context->application,
+				  info->response_source_buffer,
 				  thread))
     {
       gdk_threads_leave();
-      ochusha_async_buffer_wait(info->dat_buffer,
+      ochusha_async_buffer_wait(info->response_source_buffer,
 				"bbs_thread_ui.c: each_response_cb()");
       gdk_threads_enter();
     }
@@ -970,7 +971,7 @@ render_response(OchushaBBSThread *thread, gint number,
       parse_text(&context->handler, context, response->name, -1);
       bbs_thread_view_pop_tags(view, context->bold_tag);
     }
-  else
+  else if (strcmp(response->mailto, "sage") != 0)
     {
       gchar *name = simple_string_canon(response->name, -1,
 					context->handler.converter);
@@ -980,6 +981,16 @@ render_response(OchushaBBSThread *thread, gint number,
       G_FREE(mailto);
       G_FREE(name);
     }
+  else
+    {
+      gchar *name = simple_string_canon(response->name, -1,
+					context->handler.converter);
+      gchar *mailto = convert_string(context->handler.converter,
+				     response->mailto, -1);
+      bbs_thread_view_append_text_as_sage(view, name, -1, mailto);
+      G_FREE(mailto);
+      G_FREE(name);
+    }
   bbs_thread_view_pop_tags(view, context->response_name_tag);
 
   bbs_thread_view_append_text(view, LARGE_COLON, 3);
@@ -1247,20 +1258,20 @@ prepare_buffer_for_popup(OchushaApplication *application,
   *response_to = to;
 
   /*
-   * ΤȤɽƤ륹ɬdat_buffer˥ХåեäƤ뤬
-   * ⤷Ŭʥߥ󥰤ǲ٤⤷ʤΤǡΤ(
-   * 夫Τɤ߹)ɤĤƤ
+   * ǶΥɤǤɽƤ륹ɬresponse_source_buffer˥Хåե
+   * äƤ뤬⤷Ŭʥߥ󥰤ǲ٤⤷ʤΤǡ
+   * Τ(å夫Τɤ߹)ɤĤƤ
    */
-  if (info->dat_buffer != NULL)
+  if (info->response_source_buffer != NULL)
     {
-      *buffer = info->dat_buffer;
+      *buffer = info->response_source_buffer;
       return TRUE;
     }
 
   *buffer = ochusha_bbs_thread_get_responses_source(thread,
 					application->broker,
 					OCHUSHA_NETWORK_BROKER_CACHE_ONLY);
-  info->dat_buffer = *buffer;
+  info->response_source_buffer = *buffer;
 
   return (*buffer != NULL);
 }
@@ -1781,7 +1792,7 @@ refresh_thread(OchushaApplication *application, GtkWidget *widget,
 	}
       job = G_NEW0(WorkerJob, 1);
       job_args = G_NEW0(BBSThreadJobArgs, 1);
-      old_buffer = info->dat_buffer;
+      old_buffer = info->response_source_buffer;
       buffer = ochusha_bbs_thread_get_responses_source(thread,
 				application->broker,
 				OCHUSHA_NETWORK_BROKER_CACHE_TRY_UPDATE);
@@ -1799,7 +1810,7 @@ refresh_thread(OchushaApplication *application, GtkWidget *widget,
 
       setup_for_tab_label_animation(buffer, tab_label);
 
-      info->dat_buffer = buffer;
+      info->response_source_buffer = buffer;
       info->rendering_done = FALSE;
 
       job_args->application = application;
@@ -1867,9 +1878,11 @@ void
 jump_to_new_comer_response(GtkWidget *widget, OchushaBBSThread *thread)
 {
   BBSThreadView *view;
+  BBSThreadGUIInfo *info;
   g_return_if_fail(widget != NULL && OCHUSHA_IS_BBS_THREAD(thread));
 
   view = BBS_THREAD_VIEW(widget);
-  bbs_thread_view_scroll_to_mark(view,
-				 ensure_bbs_thread_info(thread)->last_read);
+  info = ensure_bbs_thread_info(thread);
+  if (info->last_read != NULL)
+    bbs_thread_view_scroll_to_mark(view, info->last_read);
 }
