@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: board_properties.c,v 1.3 2003/06/06 19:37:23 fuyu Exp $
+ * $Id: board_properties.c,v 1.4 2003/06/12 04:14:43 fuyu Exp $
  */
 
 #include "config.h"
@@ -112,7 +112,7 @@ open_board_properties(OchushaApplication *application,
   GtkWidget *frame;
   GtkWidget *tmp_widget;
   DialogStates *states;
-  BulletinBoardGUIInfo *info = ensure_bulletin_board_info(board);
+  BulletinBoardGUIInfo *info = ensure_bulletin_board_info(board, application);
 
   BOARD_PROPERTIES_LOCK;
 
