@@ -80,13 +80,13 @@ extern void ochusha_marshal_BOOLEAN__ENUM_INT (GClosure     *closure,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);
 
-/* BOOLEAN:POINTER (marshal.list:14) */
-extern void ochusha_marshal_BOOLEAN__POINTER (GClosure     *closure,
-                                              GValue       *return_value,
-                                              guint         n_param_values,
-                                              const GValue *param_values,
-                                              gpointer      invocation_hint,
-                                              gpointer      marshal_data);
+/* BOOLEAN:OBJECT (marshal.list:14) */
+extern void ochusha_marshal_BOOLEAN__OBJECT (GClosure     *closure,
+                                             GValue       *return_value,
+                                             guint         n_param_values,
+                                             const GValue *param_values,
+                                             gpointer      invocation_hint,
+                                             gpointer      marshal_data);
 
 /* BOOLEAN:BOXED,POINTER,STRING (marshal.list:15) */
 extern void ochusha_marshal_BOOLEAN__BOXED_POINTER_STRING (GClosure     *closure,
