@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.c,v 1.13 2003/06/07 14:35:31 fuyu Exp $
+ * $Id: ochusha_ui.c,v 1.18 2003/06/21 16:23:53 fuyu Exp $
  */
 
 #include "config.h"
@@ -192,6 +192,13 @@ ochusha_init_application(OchushaApplication *application)
       MAIN_MENU_REFRESH_BOARDLIST,
       NULL
     },
+    {
+      _("/Board/Hide hidden boardlist items"),
+      NULL,
+      main_menu_callback,
+      MAIN_MENU_HIDE_HIDDEN_BOARDLIST_ITEMS,
+      "<CheckItem>",
+    },
     {
       _("/_Thread"),
       NULL,
@@ -234,6 +241,13 @@ ochusha_init_application(OchushaApplication *application)
       MAIN_MENU_REFRESH_THREADLIST_ALL,
       NULL
     },
+    {
+      _("/Thread/Hide hidden threads"),
+      NULL,
+      main_menu_callback,
+      MAIN_MENU_HIDE_HIDDEN_THREADS,
+      "<CheckItem>",
+    },
     {
       _("/_Help"),
       NULL,
@@ -253,6 +267,7 @@ ochusha_init_application(OchushaApplication *application)
   gint nmenu_items = sizeof(menu_items) / sizeof(menu_items[0]);
 
   GdkGeometry geometry = { 0, 0, 0, 0, 0, 0, 0, 0, 0.0, 0.0, 0 };
+  GtkCheckMenuItem *item;
 
   if (pthread_mutex_init(&main_ui_lock, NULL) != 0)
     {
@@ -312,6 +327,17 @@ ochusha_init_application(OchushaApplication *application)
   /* ochusha_set_main_menu_sensitive(MAIN_MENU_OPEN_URL, FALSE); */
   ochusha_set_main_menu_sensitive(MAIN_MENU_REFRESH_THREAD_ALL, FALSE);
   /* ochusha_set_main_menu_sensitive(MAIN_MENU_ABOUT, FALSE); */
+
+  item = GTK_CHECK_MENU_ITEM(gtk_item_factory_get_widget_by_action(
+				main_menu_item_factory,
+				MAIN_MENU_HIDE_HIDDEN_BOARDLIST_ITEMS));
+  gtk_check_menu_item_set_active(item,
+				 application->hide_hidden_boardlist_items);
+  item = GTK_CHECK_MENU_ITEM(gtk_item_factory_get_widget_by_action(
+				main_menu_item_factory,
+				MAIN_MENU_HIDE_HIDDEN_THREADS));
+  gtk_check_menu_item_set_active(item,
+				 application->hide_hidden_threads);
 #if TRACE_MEMORY_USAGE
   g_signal_connect(G_OBJECT(application->menu_bar), "destroy",
 		   G_CALLBACK(gtk_widget_destroyed), &application->menu_bar);
@@ -448,7 +474,7 @@ ochusha_open_url(OchushaApplication *application, const gchar *url,
   unsigned int thread_num;
   unsigned int from;
   unsigned int to;
-  char dat_filename[PATH_MAX];
+  char thread_id[PATH_MAX];
 
   /*
    * XXX: Ǥurl2chURLɤĴ٤Ƥۤˤ餷Ƥ뤬
@@ -489,8 +515,8 @@ ochusha_open_url(OchushaApplication *application, const gchar *url,
       return;
     }
 
-  snprintf(dat_filename, PATH_MAX, "%d.dat", thread_num);
-  ochusha_open_thread(application, board, thread, dat_filename, from, in_tab);
+  snprintf(thread_id, PATH_MAX, "%d.dat", thread_num);
+  ochusha_open_thread(application, board, thread, thread_id, from, in_tab);
 }
 
 
@@ -660,6 +686,27 @@ main_menu_callback(gpointer data, guint action, GtkWidget *widget)
       refresh_boardlist(application);
       return;
 
+    case MAIN_MENU_HIDE_HIDDEN_BOARDLIST_ITEMS:
+    case MAIN_MENU_HIDE_HIDDEN_THREADS:
+      {
+	GtkCheckMenuItem *item
+	  = GTK_CHECK_MENU_ITEM(gtk_item_factory_get_widget_by_action(
+							main_menu_item_factory,
+							action));
+	if (action == MAIN_MENU_HIDE_HIDDEN_BOARDLIST_ITEMS)
+	  {
+	    application->hide_hidden_boardlist_items
+	      = gtk_check_menu_item_get_active(item);
+	    if (application->boardlist_view != NULL)
+	      redraw_boardlist(application);
+	  }
+	else
+	  application->hide_hidden_threads
+	    = gtk_check_menu_item_get_active(item);
+
+	return;
+      }
+
     case MAIN_MENU_REFRESH_THREAD:
       refresh_current_thread(application);
       return;
@@ -736,6 +783,7 @@ write_optional_prefs(FILE *file, gpointer user_data)
 				  thread_tab_enable_tooltips);
   OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application,
 				  show_threadlist_entry_when_thread_selected);
+  OUTPUT_CONFIG_ATTRIBUTE_STRING(file, application, threadlist_view_contents);
 
   OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application, enable_popup_title);
   OUTPUT_CONFIG_ATTRIBUTE_INT(file, application, popup_title_delay);
@@ -755,6 +803,10 @@ write_optional_prefs(FILE *file, gpointer user_data)
 				   user_default_filter.rule);
   OUTPUT_CONFIG_ATTRIBUTE_INT(file, application,
 			      user_default_filter.ignore_threshold);
+
+  OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application,
+				  hide_hidden_boardlist_items);
+  OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application, hide_hidden_threads);
 }
 
 
@@ -811,12 +863,13 @@ configure_application(OchushaApplication *application)
 
 
       /* 쥿Υݥåץå״Ϣ */
-      application->enable_popup_title = FALSE;
+      application->enable_popup_title = OCHUSHA_DEFAULT_ENABLE_POPUP_TITLE;
       application->popup_title_delay = OCHUSHA_DEFAULT_POPUP_DELAY;
 
 
       /* 쥹Υݥåץå״Ϣ */
-      application->enable_popup_response = TRUE;
+      application->enable_popup_response
+	= OCHUSHA_DEFAULT_ENABLE_POPUP_RESPONSE;
       application->popup_response_delay = OCHUSHA_DEFAULT_POPUP_DELAY;
       application->popup_close_delay = OCHUSHA_DEFAULT_POPUP_CLOSE_DELAY;
       application->enable_smart_popup_placement = FALSE;
@@ -825,8 +878,16 @@ configure_application(OchushaApplication *application)
 
       application->show_threadlist_entry_when_thread_selected
 	= OCHUSHA_DEFAULT_SHOW_THREADLIST_ENTRY_WHEN_THREAD_SELECTED;
+      application->hide_hidden_boardlist_items
+	= OCHUSHA_DEFAULT_HIDE_HIDDEN_BOARDLIST_ITEMS;
+      application->hide_hidden_threads
+	= OCHUSHA_DEFAULT_HIDE_HIDDEN_THREADS;
     }
 
+  if (application->threadlist_view_contents == NULL)
+    application->threadlist_view_contents
+      = G_STRDUP(OCHUSHA_DEFAULT_THREADLIST_VIEW_CONTENTS);
+
 #if ENABLE_RENDERING_ON_IDLE
   if (application->rendering_unit < 0)
     application->rendering_unit = 0;
@@ -962,6 +1023,13 @@ read_optional_prefs(GHashTable *pref_attrs, gpointer user_data)
     application->show_threadlist_entry_when_thread_selected
       = OCHUSHA_DEFAULT_SHOW_THREADLIST_ENTRY_WHEN_THREAD_SELECTED;
 
+  if (g_hash_table_lookup(pref_attrs, "threadlist_view_contents") != NULL)
+    application->threadlist_view_contents
+      = ochusha_utils_get_attribute_string(pref_attrs,
+					   "threadlist_view_contents");
+  else
+    application->threadlist_view_contents
+      = G_STRDUP(OCHUSHA_DEFAULT_THREADLIST_VIEW_CONTENTS);
 
   if (g_hash_table_lookup(pref_attrs, "enable_popup_title") != NULL)
     application->enable_popup_title
@@ -1017,6 +1085,12 @@ read_optional_prefs(GHashTable *pref_attrs, gpointer user_data)
   application->user_default_filter.ignore_threshold
     = ochusha_utils_get_attribute_int(pref_attrs,
 				      "user_default_filter.ignore_threshold");
+
+  application->hide_hidden_boardlist_items
+    = ochusha_utils_get_attribute_boolean(pref_attrs,
+					  "hide_hidden_boardlist_items");
+  application->hide_hidden_threads
+    = ochusha_utils_get_attribute_boolean(pref_attrs, "hide_hidden_threads");
 }
 
 
