@@ -23,12 +23,14 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: paned_notebook.c,v 1.2 2003/05/14 18:48:52 fuyu Exp $
+ * $Id: paned_notebook.c,v 1.3 2003/06/06 19:37:23 fuyu Exp $
  */
 
-#include "ochusha_private.h"
-#include "ochusha_ui.h"
+#include "config.h"
 
+#include "ochusha_private.h"
+
+#include "ochusha_ui.h"
 #include "paned_notebook.h"
 
 #include "marshal.h"
@@ -487,6 +489,18 @@ fake_close_signal(ItemViewRelation *relation, PanedNotebook *paned_notebook)
 }
 
 
+#if TRACE_MEMORY_USAGE
+static void
+trace_free(gpointer pointer)
+{
+  G_FREE(pointer);
+}
+#define TRACE_FREE	trace_free
+#else
+#define TRACE_FREE	g_free
+#endif
+
+
 static void
 paned_notebook_destroy(GtkObject *object)
 {
@@ -497,7 +511,7 @@ paned_notebook_destroy(GtkObject *object)
       g_slist_foreach(paned_notebook->items_shown,
 		      (GFunc)fake_close_signal, paned_notebook);
       g_slist_foreach(paned_notebook->items_shown,
-		      (GFunc)free, NULL);
+		      (GFunc)TRACE_FREE, NULL);
       g_slist_free(paned_notebook->items_shown);
       paned_notebook->items_shown = NULL;
     }
@@ -949,7 +963,7 @@ item_view_relation_new(gpointer item, GtkWidget *item_view,
 		       GtkWidget *menu_item, GtkWidget *tab_label)
 {
   ItemViewRelation *relation
-    = (ItemViewRelation *)g_malloc(sizeof(ItemViewRelation));
+    = (ItemViewRelation *)G_MALLOC(sizeof(ItemViewRelation));
   relation->item = item;
   relation->item_view = item_view;
   relation->menu_item = menu_item;
@@ -1256,7 +1270,7 @@ close_nth_page(PanedNotebook *paned_notebook, gint page)
   menu_item = relation->menu_item;
   paned_notebook->items_shown = g_slist_remove(paned_notebook->items_shown,
 					       relation);
-  g_free(relation);
+  G_FREE(relation);
 
   if (paned_notebook->current_item_view == widget)
     {
