@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_thread.c,v 1.6 2003/06/07 14:35:32 fuyu Exp $
+ * $Id: ochusha_bbs_thread.c,v 1.7 2003/06/12 04:13:38 fuyu Exp $
  */
 
 #include "config.h"
@@ -171,6 +171,7 @@ ochusha_bbs_thread_class_init(OchushaBBSThreadClass *klass)
   klass->get_url = NULL;
   klass->get_url_to_post = NULL;
   klass->check_url = NULL;
+  klass->remove_cache = NULL;
 }
 
 
@@ -518,6 +519,20 @@ ochusha_bbs_thread_check_url(OchushaBBSThread *thread, const char *url,
 }
 
 
+void
+ochusha_bbs_thread_remove_cache(OchushaBBSThread *thread,
+				OchushaConfig *config)
+{
+  OchushaBBSThreadClass *klass;
+  g_return_if_fail(OCHUSHA_IS_BBS_THREAD(thread));
+
+  klass = OCHUSHA_BBS_THREAD_GET_CLASS(thread);
+  g_return_if_fail(klass->remove_cache != NULL);
+
+  return (*klass->remove_cache)(thread, config);
+}
+
+
 static void
 ochusha_bbs_thread_read_threadlist_element(OchushaBBSThread *thread,
 					   GHashTable *thread_attributes)
