@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_thread.h,v 1.4 2003/05/25 08:46:16 fuyu Exp $
+ * $Id: ochusha_bbs_thread.h,v 1.5 2003/06/12 04:13:38 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BBS_THREAD_H_
@@ -111,6 +111,7 @@ struct _OchushaBBSThreadClass
   const char *(*get_url_to_post)(OchushaBBSThread *thread);
   gboolean (*check_url)(OchushaBBSThread *thread, const char *url,
 			unsigned int *from_p, unsigned int *to_p);
+  void (*remove_cache)(OchushaBBSThread *thread, OchushaConfig *config);
 
   gboolean (*preview_response)(OchushaBBSThread *thread,
 			       const OchushaBBSResponse *response,
@@ -181,6 +182,8 @@ gboolean ochusha_bbs_thread_parse_responses(OchushaBBSThread *thread,
 					    EachResponseCallback *response_cb,
 					    EndThreadCallback *end_cb,
 					    gpointer callback_data);
+void ochusha_bbs_thread_remove_cache(OchushaBBSThread *thread,
+				     OchushaConfig *config);
 
 gboolean ochusha_bbs_thread_preview_response(OchushaBBSThread *thread,
 					const OchushaBBSResponse *response,
