@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bulletin_board.c,v 1.6 2003/06/07 14:35:32 fuyu Exp $
+ * $Id: ochusha_bulletin_board.c,v 1.8 2003/06/20 18:10:06 fuyu Exp $
  */
 
 #include "config.h"
@@ -544,6 +544,13 @@ ochusha_bulletin_board_get_response_character_encoding(
 /*
  * boardlist.xmlϢ
  */
+#define OUTPUT_BOARD_ATTRIBUTE_BOOLEAN(file, board, attribute)		\
+  fprintf(file,								\
+	  "        <attribute name=\"" #attribute	"\">\n"		\
+	  "          <boolean val=\"%s\"/>\n"				\
+	  "        </attribute>\n",					\
+	  (board)->attribute ? "true" : "false")
+
 #define OUTPUT_BOARD_ATTRIBUTE_INT(file, board, attribute)		\
   fprintf(file,								\
 	  "        <attribute name=\"" #attribute	"\">\n"		\
@@ -565,13 +572,8 @@ static void
 ochusha_bulletin_board_read_boardlist_element(OchushaBulletinBoard *board,
 					      GHashTable *board_attributes)
 {
-  /*
-   * boardlist.xmlɤ߹߻bbs_type˹碌OchushaBulletinBoard
-   * ֥饹֥ȤۤƤơġOchushaBulletinBoard
-   * եɤɬܤͤϥ󥹥ȥ饯ΰȤͿƤ롣
-   *
-   * XXX: flagsɲä뤫⤷ʤ
-   */
+  board->hidden = ochusha_utils_get_attribute_boolean(board_attributes,
+						      "hidden");
 }
 
 
@@ -582,6 +584,7 @@ ochusha_bulletin_board_write_boardlist_element(OchushaBulletinBoard *board,
   OUTPUT_BOARD_ATTRIBUTE_INT(boardlist_xml, board, bbs_type);
   OUTPUT_BOARD_ATTRIBUTE_STRING(boardlist_xml, board, name);
   OUTPUT_BOARD_ATTRIBUTE_STRING(boardlist_xml, board, base_url);
+  OUTPUT_BOARD_ATTRIBUTE_BOOLEAN(boardlist_xml, board, hidden);
 }
 
 
@@ -967,7 +970,7 @@ ochusha_bulletin_board_read_threadlist_xml(OchushaBulletinBoard *board,
 
   xmlInitParser();
 
-  sax_handler.initialized = 0;
+  memset(&sax_handler, 0, sizeof(xmlSAXHandler));
   initxmlDefaultSAXHandler(&sax_handler, TRUE);
 
   sax_handler.getEntity = getEntityHandler;
