@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bulletin_board.h,v 1.3 2003/05/25 08:46:16 fuyu Exp $
+ * $Id: ochusha_bulletin_board.h,v 1.4 2003/06/20 18:10:06 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BULLETIN_BOARD_H_
@@ -83,6 +83,9 @@ struct _OchushaBulletinBoard
   GSList *dropped_list;		/* DAT(OchushaBBSThread *)ꥹ */
 
   OchushaBBSType bbs_type;	/* ǼĤμࡽ2chΤߤ */
+
+  gboolean hidden;		/* İ鱣 */
+  gboolean killed;		/* İ¸˼ΤƤ */
 };
 
 
