@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_config.c,v 1.6 2003/06/07 14:35:32 fuyu Exp $
+ * $Id: ochusha_config.c,v 1.8 2003/06/12 04:12:43 fuyu Exp $
  */
 
 #include "config.h"
@@ -301,9 +301,8 @@ ochusha_config_cache_unlink_file(const OchushaConfig *config, const char *url)
   if (cur_pos == NULL)
     return;
 
-  /* Ĺʡ */
-  len = snprintf(buffer, PATH_MAX, "%s/cache/%s", config->home,
-		 url + 7);	/* "http://"ʬά */
+  len = snprintf(buffer, PATH_MAX, "cache/%s", url + 7);
+  					       /* "http://"ʬά */
 
   if (len >= PATH_MAX)
     return;
@@ -771,7 +770,7 @@ ochusha_read_config_xml(OchushaConfig *config,
 
   xmlInitParser();
 
-  sax_handler.initialized = 0;
+  memset(&sax_handler, 0, sizeof(xmlSAXHandler));
   initxmlDefaultSAXHandler(&sax_handler, TRUE);
 
   sax_handler.getEntity = getEntityHandler;
