@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_network_broker.c,v 1.4 2003/06/07 14:35:32 fuyu Exp $
+ * $Id: ochusha_network_broker.c,v 1.5 2003/06/10 21:02:55 fuyu Exp $
  */
 
 #include "config.h"
@@ -411,8 +411,9 @@ setup_common_request_headers(const OchushaConfig *config,
 typedef enum
 {
   UNKNOWN_ENCODING = -1,
-  STANDARD_ENCODING,
+  IDENTITY_ENCODING,
   GZIP_ENCODING,
+  DEFLATE_ENCODING,
 } ContentEncodingType;
 
 
@@ -425,11 +426,17 @@ get_content_encoding_type(ghttp_request *request)
     {
       if (strcmp(encoding, "gzip") == 0)
 	return GZIP_ENCODING;
-      else
-	return UNKNOWN_ENCODING;
+#if 1 || DEBUG_NETWORK
+      fprintf(stderr, "Content-Encoding: %s\n", encoding);
+#endif
+      if (strcmp(encoding, "deflate") == 0)
+	return DEFLATE_ENCODING;
+      if (strcmp(encoding, "identity") == 0)
+	return IDENTITY_ENCODING;
+      return UNKNOWN_ENCODING;
     }
 
-  return STANDARD_ENCODING;
+  return IDENTITY_ENCODING;
 }
 
 
@@ -490,7 +497,7 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 #if DISABLE_PERSISTENT_CONNECTION
   ghttp_set_header(request, http_hdr_Connection, "close");
 #endif
-  ghttp_set_header(request, http_hdr_Accept_Encoding, "gzip");
+  ghttp_set_header(request, http_hdr_Accept_Encoding, "deflate, gzip");
 
   if (if_modified_since != NULL
       && ochusha_config_cache_file_exist(broker->config, url))
@@ -613,7 +620,7 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
   ghttp_set_uri(request, (char *)url);
   ghttp_set_type(request, ghttp_type_get);
   ghttp_set_header(request, http_hdr_Connection, "close");
-  ghttp_set_header(request, http_hdr_Accept_Encoding, "gzip");
+  ghttp_set_header(request, http_hdr_Accept_Encoding, "deflate, gzip");
   if (!setup_common_request_headers(broker->config, request))
     {
       g_signal_emit(G_OBJECT(broker),
@@ -681,16 +688,27 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 		    }
 		  break;
 
+		case DEFLATE_ENCODING:
+		  gzip_buffer = gzip_buffer_new(buffer);
+		  if (gzip_buffer == NULL)
+		    {
+		      error_message = _("Out of memory.");
+		      goto error_exit;
+		    }
+		  gzip_buffer_skip_gzip_header(gzip_buffer);
+		  break;
+
 		case UNKNOWN_ENCODING:
 		  error_message = _("Unknown transfer encoding.");
 		  goto error_exit;
 
-		case STANDARD_ENCODING:
+		case IDENTITY_ENCODING:
 		  break;
 		}
 	    }
 
-	  if (content_encoding == GZIP_ENCODING)
+	  if (content_encoding == GZIP_ENCODING
+	      || content_encoding == DEFLATE_ENCODING)
 	    {
 	      GzipBufferStatus result
 		= gzip_buffer_append_data(gzip_buffer, body, body_len);
@@ -713,7 +731,7 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 	    }
 	  else if (!ochusha_async_buffer_append_data(buffer, body, body_len,
 					"network.c: http_read_from_url"))
-	    {	/* content_encoding == STANDARD_ENCODING */
+	    {	/* content_encoding == IDENTITY_ENCODING */
 	      g_signal_emit(G_OBJECT(broker),
 			    broker_signals[ACCESS_TERMINATED_SIGNAL],
 			    0,
@@ -963,7 +981,9 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
       ghttp_set_header(request, http_hdr_Connection, "close");
 #endif
 #if ENABLE_GZIPPED_DIFFERENCIAL_READ
-      ghttp_set_header(request, http_hdr_Accept_Encoding, "gzip");
+      ghttp_set_header(request, http_hdr_Accept_Encoding, "deflate, gzip");
+#else
+      ghttp_set_header(request, http_hdr_Accept_Encoding, "deflate");
 #endif
 
       if (args->if_modified_since != NULL)
@@ -1095,7 +1115,9 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 	  ghttp_set_type(request, ghttp_type_get);
 	  ghttp_set_header(request, http_hdr_Connection, "close");
 #if ENABLE_GZIPPED_DIFFERENCIAL_READ
-	  ghttp_set_header(request, http_hdr_Accept_Encoding, "gzip");
+	  ghttp_set_header(request, http_hdr_Accept_Encoding, "deflate, gzip");
+#else
+	  ghttp_set_header(request, http_hdr_Accept_Encoding, "deflate");
 #endif
 
 #if DEBUG_NETWORK_MOST
@@ -1225,15 +1247,26 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 			    }
 			  break;
 
+			case DEFLATE_ENCODING:
+			  gzip_buffer = gzip_buffer_new(buffer);
+			  if (gzip_buffer == NULL)
+			    {
+			      error_message = _("Out of memory.");
+			      goto error_exit;
+			    }
+			  gzip_buffer_skip_gzip_header(gzip_buffer);
+			  break;
+
 			case UNKNOWN_ENCODING:
 			  goto cache_is_dirty;	/* ĩ */
 
-			case STANDARD_ENCODING:
+			case IDENTITY_ENCODING:
 			  break;
 			}
 		    }
 
-		  if (content_encoding == GZIP_ENCODING)
+		  if (content_encoding == GZIP_ENCODING
+		      || content_encoding == DEFLATE_ENCODING)
 		    {
 		      GzipBufferStatus result
 			= gzip_buffer_append_data(gzip_buffer, body, body_len);
@@ -1257,7 +1290,7 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 		  else if (!ochusha_async_buffer_append_data(buffer, body,
 			      body_len,
 			      "ochusha_network_broker.c: try_update_cache()"))
-		    {	/* content_encoding == STANDARD_ENCODING */
+		    {	/* content_encoding == IDENTITY_ENCODING */
 		      g_signal_emit(G_OBJECT(args->broker),
 				broker_signals[ACCESS_TERMINATED_SIGNAL],
 				0,
