@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_2ch.c,v 1.6 2003/06/07 14:35:32 fuyu Exp $
+ * $Id: ochusha_thread_2ch.c,v 1.7 2003/06/12 04:13:38 fuyu Exp $
  */
 
 #include "config.h"
@@ -64,6 +64,8 @@ static gboolean ochusha_thread_2ch_check_url(OchushaBBSThread *thread,
 					     const char *url,
 					     unsigned int *from_p,
 					     unsigned int *to_p);
+static void ochusha_thread_2ch_remove_cache(OchushaBBSThread *thread,
+					    OchushaConfig *config);
 
 static OchushaAsyncBuffer *ochusha_thread_2ch_get_responses_source(
 					OchushaBBSThread *thread,
@@ -143,6 +145,7 @@ ochusha_thread_2ch_class_init(OchushaThread2chClass *klass)
     = (const char *(*)(OchushaBBSThread *))ochusha_thread_2ch_get_base_url;
   b_class->get_url_to_post = ochusha_thread_2ch_get_url_to_post;
   b_class->check_url = ochusha_thread_2ch_check_url;
+  b_class->remove_cache = ochusha_thread_2ch_remove_cache;
 
 #if 0
   b_class->preview_response = NULL;
@@ -339,6 +342,19 @@ ochusha_thread_2ch_check_url(OchushaBBSThread *thread, const char *url,
 }
 
 
+static void
+ochusha_thread_2ch_remove_cache(OchushaBBSThread *thread,
+				OchushaConfig *config)
+{
+  const char *dat_url;
+  g_return_if_fail(OCHUSHA_IS_THREAD_2CH(thread) && config != NULL);
+
+  dat_url = ochusha_thread_2ch_get_dat_url(OCHUSHA_THREAD_2CH(thread));
+  if (dat_url != NULL)
+    ochusha_config_cache_unlink_file(config, dat_url);
+}
+
+
 OchushaBBSThread *
 ochusha_thread_2ch_new(OchushaBoard2ch *board,
 		       const char *dat_filename,
