@@ -23,16 +23,19 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_utils_2ch.c,v 1.1.1.1 2003/05/10 16:34:28 fuyu Exp $
+ * $Id: ochusha_utils_2ch.c,v 1.4 2003/06/07 14:35:32 fuyu Exp $
  */
 
-#include "ochusha.h"
-#include "ochusha_private.h"
+#include "config.h"
 
+#include "ochusha_private.h"
+#include "ochusha.h"
 #include "ochusha_bbs_table.h"
 #include "ochusha_board_2ch.h"
 #include "ochusha_utils_2ch.h"
 
+#include "utils.h"
+
 #include <glib.h>
 
 #include <stdio.h>
@@ -44,12 +47,11 @@
 
 
 OchushaAsyncBuffer *
-ochusha_utils_2ch_get_bbsmenu(OchushaConfig *conf,
-			      OchushaNetworkCallbacks *callbacks,
-			      gpointer callback_data)
+ochusha_utils_2ch_get_bbsmenu(OchushaNetworkBroker *broker)
 {
-  return ochusha_read_from_url(conf, conf->bbsmenu_url, NULL,
-			       OCHUSHA_CACHE_IGNORE, callbacks, callback_data);
+  return ochusha_network_broker_read_from_url(broker,
+				broker->config->bbsmenu_url, NULL,
+				OCHUSHA_NETWORK_BROKER_CACHE_IGNORE);
 }
 
 
@@ -107,7 +109,7 @@ extract_boards(OchushaBBSTable *table, OchushaBoardCategory *category,
       }
 #endif
       name = convert_string(converter, tag_tail + 1, close_tag - tag_tail - 1);
-      url = g_strndup(cur_pos, url_tail - cur_pos);
+      url = G_STRNDUP(cur_pos, url_tail - cur_pos);
 #if GUESS_2CH_BOARD_URL
       if (!is_2ch_board_url(url))
 	goto search_next;
@@ -122,7 +124,7 @@ extract_boards(OchushaBBSTable *table, OchushaBoardCategory *category,
 #endif
 	  if (name == NULL)
 	    {
-	      g_free(url);
+	      G_FREE(url);
 	      return FALSE;	/* Out of memory */
 	    }
 
@@ -180,6 +182,7 @@ extract_boards(OchushaBBSTable *table, OchushaBoardCategory *category,
 		    }
 		}
 	      ochusha_bbs_table_add_board(table, board);
+	      g_object_unref(G_OBJECT(board));
 	    }
 	}
       
@@ -187,9 +190,9 @@ extract_boards(OchushaBBSTable *table, OchushaBoardCategory *category,
 
     search_next:
       if (url != NULL)
-	g_free(url);
+	G_FREE(url);
       if (name != NULL)
-	g_free(name);
+	G_FREE(name);
       /* (HTMLA)õ*/
       cur_pos = g_strstr_len(close_tag + 4, tail - close_tag, "<A HREF=http");
       if (cur_pos == NULL)
@@ -230,8 +233,15 @@ ochusha_utils_2ch_analyze_bbsmenu(OchushaBBSTable *table,
 {
   gboolean result = TRUE;
   iconv_t converter;
+  OchushaNetworkBrokerBufferStatus *status;
 
-  g_return_val_if_fail(OCHUSHA_IS_BBS_TABLE(table) && buffer != NULL, FALSE);
+  g_return_val_if_fail(OCHUSHA_IS_BBS_TABLE(table)
+		       && OCHUSHA_IS_ASYNC_BUFFER(buffer), FALSE);
+
+  status = g_object_get_data(G_OBJECT(buffer),
+			     "OchushaNetworkBroker::BufferStatus");
+
+  g_return_val_if_fail(status != NULL, FALSE);
 
   converter = iconv_open("UTF-8//IGNORE", "CP932");  /* ϡɥǥ */
   g_return_val_if_fail(converter != (iconv_t)-1, FALSE);
@@ -295,7 +305,7 @@ ochusha_utils_2ch_analyze_bbsmenu(OchushaBBSTable *table,
 	    category = ochusha_bbs_table_lookup_category(table, category_name);
 	    if (category == NULL)
 	      category = ochusha_board_category_new(category_name);
-	    g_free(category_name);
+	    G_FREE(category_name);
 
 	    cur_pos = end_name_pos + 4;	/* skip "</B>" */
 	    rest_of_data -= 4;
@@ -336,8 +346,8 @@ ochusha_utils_2ch_analyze_bbsmenu(OchushaBBSTable *table,
 	    break;
 	  }
 
-	if (((OchushaNetworkStatus *)buffer->user_data)->state
-	    == OCHUSHA_CACHE_IS_DIRTY)
+	if (status->state
+	    == OCHUSHA_NETWORK_BROKER_BUFFER_STATE_CACHE_IS_DIRTY)
 	  {
 	    result = FALSE;
 	    break;
@@ -452,10 +462,10 @@ ochusha_utils_2ch_parse_url(OchushaBBSTable *table, const char *url,
 
  done:
   if (server != NULL)
-    free(server);
+    G_FREE(server);
 
   if (path != NULL)
-    free(path);
+    G_FREE(path);
 
   if (result)
     {
@@ -470,7 +480,7 @@ ochusha_utils_2ch_parse_url(OchushaBBSTable *table, const char *url,
       if (to_p != NULL)
 	*to_p = to;
       if (thread_part_p != NULL)
-	*thread_part_p = g_strdup(tmp_pos + 1);
+	*thread_part_p = G_STRDUP(tmp_pos + 1);
     }
 
   return result;
