@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: utils.h,v 1.2 2003/05/14 17:14:19 fuyu Exp $
+ * $Id: utils.h,v 1.3 2003/06/06 19:38:05 fuyu Exp $
  */
 
 #ifndef _UTILS_H_
@@ -63,6 +63,17 @@ char *ochusha_utils_url_decode_string(const char *src);
 int mkdir_p(const char *path);
 
 
+#if TRACE_MEMORY_USAGE
+/*
+ * ꡼åϢ
+ */
+void init_memory_trace(void);
+void register_pointer(gpointer pointer, const char *where);
+void unregister_pointer(gpointer pointer, const char *where);
+void dump_pointers(void);
+#endif
+
+
 #ifdef __cplusplus
 } // extern "C"
 #endif
